@@ -11,8 +11,10 @@
 
 int maine(int argc, char *argv[]);
 
+#include <SDL2/SDL.h>
 #include "endless-sky/source/Angle.h"
 #include "endless-sky/source/DataNode.h"
+#include "endless-sky/source/DataFile.h"
 #include "endless-sky/source/GameData.h"
 #include "endless-sky/source/Outfit.h"
 #include "endless-sky/source/PlayerInfo.h"
@@ -68,6 +70,15 @@ PYBIND11_MODULE(bindings, m) {
         Some other explanation about the subtract function.
     )pbdoc");
 
+    m.def("saves_directory", []() {
+        // memory leak because we dont' SDL_free() this str
+        return SDL_GetPrefPath("endless-sky", "saves");
+    });
+    m.def("plugins_directory", []() {
+        // memory leak because we dont' SDL_free() this str
+        return SDL_GetPrefPath("endless-sky", "plugins");
+    });
+
     // test/src/helpers/datanode-factory
     m.def("AsDataNode", &AsDataNode);
 
@@ -84,6 +95,15 @@ PYBIND11_MODULE(bindings, m) {
         .def("Rotate", &Angle::Rotate);
     // TODO why does -= (removed) give a warning?
 
+    // source/DataFile
+    py::class_<DataFile>(m, "DataFile")
+        .def(py::init<>())
+        .def(py::init<std::string&>())
+        .def("Load", py::overload_cast<const std::string&>(&DataFile::Load))
+        .def("__iter__", [](DataFile &f) {
+            return py::make_iterator(f.begin(), f.end());
+        }, py::keep_alive<0, 1>()); // TODO is this keep_alive policy right?
+
     // source/DataNode
     py::class_<DataNode>(m, "DataNode")
         .def(py::init<DataNode*>())
